"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const adv_record_1 = require("../records/adv.record");
const db_1 = require("../utils/db");
const defaultObj = {
    // id: "[test]abcf",
    name: "Test Name",
    description: "Test Description",
    url: "https://megak.pl",
    price: 0,
    lat: 9,
    lon: 9,
};
afterAll(() => __awaiter(void 0, void 0, void 0, function* () {
    yield db_1.pool.end();
}));
test("AdvRecord returns data from database for one entry.", () => __awaiter(void 0, void 0, void 0, function* () {
    const adv = yield adv_record_1.AdvRecord.getOne("abc");
    console.log(adv);
    expect(adv).toBeDefined();
    expect(adv.id).toBe("abc");
    expect(adv.name).toBe("Testowy");
}));
test("AdvRecord.getOne returns null from database for unexisting entry.", () => __awaiter(void 0, void 0, void 0, function* () {
    const adv = yield adv_record_1.AdvRecord.getOne("---");
    expect(adv).toBeNull();
}));
test("AdvRecord.findAll returns array of found entries.", () => __awaiter(void 0, void 0, void 0, function* () {
    const adv = yield adv_record_1.AdvRecord.findAll("");
    expect(adv).not.toEqual([]);
    expect(adv[0].id).toBeDefined();
}));
test("AdvRecord.findAll returns array of found entries when searching for 'a'.", () => __awaiter(void 0, void 0, void 0, function* () {
    const adv = yield adv_record_1.AdvRecord.findAll("a");
    expect(adv).not.toEqual([]);
    expect(adv[0].id).toBeDefined();
}));
test("AdvRecord.findAll returns empty array when searching for something what not exist.", () => __awaiter(void 0, void 0, void 0, function* () {
    const adv = yield adv_record_1.AdvRecord.findAll("------------------------------------------------");
    expect(adv).toEqual([]);
}));
test("AdvRecord.findAll returns limited data.", () => __awaiter(void 0, void 0, void 0, function* () {
    const adv = yield adv_record_1.AdvRecord.findAll("");
    expect(adv[0].id).toBeDefined();
    expect(adv[0].lat).toBeDefined();
    expect(adv[0].lon).toBeDefined();
    expect(adv[0].price).toBeUndefined();
    expect(adv[0].name).toBeUndefined();
    expect(adv[0].description).toBeUndefined();
    expect(adv[0].url).toBeUndefined();
}));
test("AdvRecord.insert inserts new data and returns UUID.", () => __awaiter(void 0, void 0, void 0, function* () {
    const adv = new adv_record_1.AdvRecord(defaultObj);
    yield adv.insert();
    expect(adv.id).toBeDefined();
    expect(typeof adv.id).toBe("string");
}));
// test("AdvRecord.insert inserts data to database.", async () => {
//   const adv = new AdvRecord(defaultObj);
//
//   await adv.insert();
//
//   const foundAdv = await AdvRecord.getOne(adv.id);
//
//   expect(foundAdv).toBeDefined();
//   expect(foundAdv).not.toBeNull();
//   expect(foundAdv.id).toBe(adv.id);
// });
//# sourceMappingURL=adv.test.js.map