import { AdvRecord } from "../records/adv.record";

const defaultObj = {
  id: "abc",
  name: "Test Name",
  description: "Test Description",
  url: "https://megak.pl",
  price: 0,
  lat: 9,
  lon: 9,
};

describe("AdvRecord validation tests", () => {
  test("Can build advRecord", () => {
    const adv = new AdvRecord(defaultObj);

    expect(adv.name).toBe("Test Name");
    expect(adv.description).toBe("Test Description");
    expect(adv.url).toBe("https://megak.pl");
    expect(adv.price).toBe(0);
    expect(adv.lat).toBe(9);
    expect(adv.lon).toBe(9);
  });

  test("Validates invalid name", () => {
    expect(
      () =>
        new AdvRecord({
          ...defaultObj,
          name: "",
        })
    );

    expect(
      () =>
        new AdvRecord({
          ...defaultObj,
          name: "Lorem ipsum dolor sit amet, consectetuer adipiscing elit. Aenean commodo ligula eget dolor. Aenean massa. Cum sociis natoque penatibus et magnis dis parturient montes, nascetur ridiculus mus. Donec quam felis, ultricies nec, pellentesque eu, pretium quis, sem. Nulla consequat massa quis enim. Donec pede justo, fringilla vel, aliquet nec, vulputate eget, arcu. In enim justo, rhoncus ut, imperdiet a, venenatis vitae, justo. Nullam dictum felis eu pede mollis pretium. Integer tincidunt. Cras dapibus. Vivamus elementum semper nisi. Aenean vulputate eleifend tellus. Aenean leo ligula, porttitor eu, consequat vitae, eleifend ac, enim. Aliquam lorem ante, dapibus in, viverra quis, feugiat a, tellus.",
        })
    ).toThrow(
      "Advertisement name cannot be empty and cannot have more than 100 signs"
    );
  });

  test("Validates invalid description", () => {
    expect(
      () =>
        new AdvRecord({
          ...defaultObj,
          description:
            "Far far away, behind the word mountains, far from the countries Vokalia and Consonantia, there live the blind texts. Separated they live in Bookmarksgrove right at the coast of the Semantics, a large language ocean. A small river named Duden flows by their place and supplies it with the necessary regelialia. It is a paradisematic country, in which roasted parts of sentences fly into your mouth. Even the all-powerful Pointing has no control about the blind texts it is an almost unorthographic life One day however a small line of blind text by the name of Lorem Ipsum decided to leave for the far World of Grammar. The Big Oxmox advised her not to do so, because there were thousands of bad Commas, wild Question Marks and devious Semikoli, but the Little Blind Text didn’t listen. She packed her seven versalia, put her initial into the belt and made herself on the way. When she reached the first hills of the Italic Mountains, she had a last view back on the skyline of her hometown Bookmarksgr\n" +
            "\n",
        })
    ).toThrow("Advertisement description cannot have more than 1000 signs");
  });

  test("Validates invalid price", () => {
    expect(
      () =>
        new AdvRecord({
          ...defaultObj,
          price: -3,
        })
    ).toThrow("Price cannot be be lower than 0 and higher than 9 999 999");

    expect(
      () =>
        new AdvRecord({
          ...defaultObj,
          price: 99999991,
        })
    ).toThrow("Price cannot be be lower than 0 and higher than 9 999 999");
  });

  test("Validates invalid URL", () => {
    expect(
      () =>
        new AdvRecord({
          ...defaultObj,
          url: "",
        })
    ).toThrow(
      "Advertisement url cannot be empty and cannot have more than 100 signs"
    );

    expect(
      () =>
        new AdvRecord({
          ...defaultObj,
          url:
            "Far far away, behind the word mountains, far from the countries Vokalia and Consonantia, there live t\n" +
            "\n",
        })
    ).toThrow(
      "Advertisement url cannot be empty and cannot have more than 100 signs"
    );
  });
});
