import { AdvRecord } from "../records/adv.record";
import { pool } from "../utils/db";
import { AdvEntity } from "../types";

const defaultObj = {
  // id: "[test]abcf",
  name: "Test Name",
  description: "Test Description",
  url: "https://megak.pl",
  price: 0,
  lat: 9,
  lon: 9,
};

afterAll(async () => {
  await pool.end();
});

test("AdvRecord returns data from database for one entry.", async () => {
  const adv = await AdvRecord.getOne("abc");

  console.log(adv);
  expect(adv).toBeDefined();
  expect(adv.id).toBe("abc");
  expect(adv.name).toBe("Testowy");
});

test("AdvRecord.getOne returns null from database for unexisting entry.", async () => {
  const adv = await AdvRecord.getOne("---");

  expect(adv).toBeNull();
});

test("AdvRecord.findAll returns array of found entries.", async () => {
  const adv = await AdvRecord.findAll("");

  expect(adv).not.toEqual([]);
  expect(adv[0].id).toBeDefined();
});

test("AdvRecord.findAll returns array of found entries when searching for 'a'.", async () => {
  const adv = await AdvRecord.findAll("a");

  expect(adv).not.toEqual([]);
  expect(adv[0].id).toBeDefined();
});

test("AdvRecord.findAll returns empty array when searching for something what not exist.", async () => {
  const adv = await AdvRecord.findAll(
    "------------------------------------------------"
  );

  expect(adv).toEqual([]);
});

test("AdvRecord.findAll returns limited data.", async () => {
  const adv = await AdvRecord.findAll("");

  expect(adv[0].id).toBeDefined();
  expect(adv[0].lat).toBeDefined();
  expect(adv[0].lon).toBeDefined();
  expect((adv[0] as AdvEntity).price).toBeUndefined();
  expect((adv[0] as AdvEntity).name).toBeUndefined();
  expect((adv[0] as AdvEntity).description).toBeUndefined();
  expect((adv[0] as AdvEntity).url).toBeUndefined();
});

test("AdvRecord.insert inserts new data and returns UUID.", async () => {
  const adv = new AdvRecord(defaultObj);

  await adv.insert();

  expect(adv.id).toBeDefined();
  expect(typeof adv.id).toBe("string");
});

// test("AdvRecord.insert inserts data to database.", async () => {
//   const adv = new AdvRecord(defaultObj);
//
//   await adv.insert();
//
//   const foundAdv = await AdvRecord.getOne(adv.id);
//
//   expect(foundAdv).toBeDefined();
//   expect(foundAdv).not.toBeNull();
//   expect(foundAdv.id).toBe(adv.id);
// });
